<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * Elementor cpt Widget.
 *
 * Elementor widget that uses the cpt control.
 *
 * @since 1.0.0
 */
class Elementor_Cpt_Widget extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve cpt widget name.
     *
     * @since 1.0.0
     * @access public
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'cpt';
    }

    /**
     * Get widget title.
     *
     * Retrieve cpt widget title.
     *
     * @since 1.0.0
     * @access public
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('InsatantVA Case Studies', 'elementor-cpt-control');
    }

    /**
     * Get widget icon.
     *
     * Retrieve cpt widget icon.
     *
     * @since 1.0.0
     * @access public
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-posts-grid';
    }

    /**
     * Register cpt widget controls.
     *
     * Add input fields to allow the user to customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'elementor-cpt-control'),
                'type' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'number_of_case_post',
            [
                'label' => __('Number of Projects', 'elementor-cpt-control'),
                'type' => \Elementor\Controls_Manager::NUMBER,
                'default' => 6, // Set a default value
                'min' => 1,
                'max' => 21,
                'step' => 1,
            ]
        );
        $this->add_control(
            'selected_case',
            [
                'label' => esc_html__('Select case', 'elementor-cpt-control'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $this->get_case_options(), // Define a function to get available case options
            ]
        );
        $this->add_control(
			'selected_style',
			[
				'label' => esc_html__( 'Select Style', 'elementor-cpt-control' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style1', // Set the default style
				'options' => [
					'style1' => esc_html__( 'Style 1', 'elementor-cpt-control' ),
					'style2' => esc_html__( 'Style 2', 'elementor-cpt-control' ),
				],
			]
		);
        $this->end_controls_section();
        $this->start_controls_section(
            'query_section',
            [
                'label' => esc_html__('Query Settings', 'your-text-domain'),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label' => esc_html__('Order By', 'your-text-domain'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'ID' => esc_html__('Post ID', 'your-text-domain'),
                    'title' => esc_html__('Title', 'your-text-domain'),
                    'date' => esc_html__('Date', 'your-text-domain'),
                    // Add other options as needed
                ],
                'default' => 'ID', // Default order by Post ID
            ]
        );

        $this->add_control(
            'post_status',
            [
                'label' => esc_html__('Post Status', 'your-text-domain'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'publish' => esc_html__('Publish', 'your-text-domain'),
                    'draft' => esc_html__('Draft', 'your-text-domain'),
                    // Add other options as needed
                ],
                'default' => 'publish', // Default post status is 'publish'
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__('Order', 'your-text-domain'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'ASC' => esc_html__('Ascending', 'your-text-domain'),
                    'DESC' => esc_html__('Descending', 'your-text-domain'),
                ],
                'default' => 'ASC', // Default order is ascending
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
			'image_control_section',
			[
				'label' => esc_html__( 'Image Dimensions', 'elementor-cpt-control' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		
		$this->add_responsive_control(
			'image_width',
			[
				'label' => esc_html__( 'Image Width', 'elementor-cpt-control' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]);
		
		$this->add_responsive_control(
			'image_height',
			[
				'label' => esc_html__( 'image Height', 'elementor-cpt-control' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} img' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'object-fit',
			[
				'label' => esc_html__( 'Object Fit', 'elementor-cpt-control' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'condition' => [
					'image_height[size]!' => '',
				],
				'options' => [
					'' => esc_html__( 'Default', 'elementor-cpt-control' ),
					'fill' => esc_html__( 'Fill', 'elementor-cpt-control' ),
					'cover' => esc_html__( 'Cover', 'elementor-cpt-control' ),
					'contain' => esc_html__( 'Contain', 'elementor-cpt-control' ),
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} img' => 'object-fit: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'object-position',
			[
				'label' => esc_html__( 'Object Position', 'elementor-cpt-control' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'center center' => esc_html__( 'Center Center', 'elementor-cpt-control' ),
					'center left' => esc_html__( 'Center Left', 'elementor-cpt-control' ),
					'center right' => esc_html__( 'Center Right', 'elementor-cpt-control' ),
					'top center' => esc_html__( 'Top Center', 'elementor-cpt-control' ),
					'top left' => esc_html__( 'Top Left', 'elementor-cpt-control' ),
					'top right' => esc_html__( 'Top Right', 'elementor-cpt-control' ),
					'bottom center' => esc_html__( 'Bottom Center', 'elementor-cpt-control' ),
					'bottom left' => esc_html__( 'Bottom Left', 'elementor-cpt-control' ),
					'bottom right' => esc_html__( 'Bottom Right', 'elementor-cpt-control' ),
				],
				'default' => 'center center',
				'selectors' => [
					'{{WRAPPER}} img' => 'object-position: {{VALUE}};',
				],
				'condition' => [
					'object-fit' => 'cover',
				],
			]
		);
		
		$this->end_controls_section();	
    }

    private function get_case_options()
    {
        $options = [];
        $args = array(
            'post_type' => 'case_study',
            'posts_per_page' => -1,
            'post_status' => 'publish',
        );
        $case = new WP_Query($args);

        if ($case->have_posts()) {
            while ($case->have_posts()) {
                $case->the_post();
                $options[get_the_ID()] = get_the_title();
            }
            wp_reset_postdata();
        }

        return $options;
    }

    /**
     * Render cpt widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render()
{
    $settings = $this->get_settings_for_display();
    $number_of_case_post = $settings['number_of_case_post'];
	$selected_style = $settings['selected_style'];
    $selected_case = $settings['selected_case'];
    $args = array(
        'post_type' => 'case_study',
        'orderby' => $this->get_settings('orderby'),
        'post_status' => $this->get_settings('post_status'),
        'order' => $this->get_settings('order'),
        'posts_per_page' => $number_of_case_post,
        'post__in' => $selected_case, // Include only the selected case
    );

    $result = new WP_Query($args);
    if ($selected_style === 'style1') {
    echo '<section class="case_studies_section">';
    if ($result->have_posts()) {
        echo '<div class="container">';
        echo '<div class="row" data-aos="fade-up">';
        while ($result->have_posts()) {
            $result->the_post();
            $url = wp_get_attachment_url(get_post_thumbnail_id(), "post_thumbnail");
            $meta = get_post_meta(get_the_ID(), 'post_thumbnail', true);
            ?>
                <div class="col-lg-4 col-md-4 col-sm-6 col-xs-12">
                    <div class="case_studies_image">
                        <figure class="mb-0"><img src="<?php echo $url ?>" alt="" class="img-fluid"></figure>
                        <div class="case_studies_box">
                            <h4><?php echo get_the_title(); ?></h4>
                            <p><?php echo wp_trim_words(get_the_content(), 6) ?></p>
                            <a href="<?php echo get_post_permalink(); ?>">
                                <i class="fa-solid fa-arrow-right"></i>
                            </a>
                        </div>
                    </div>
                </div>
            <?php
        }
        echo '</div>';
        echo '</div>';
    }
    echo '</section>';
    }
    elseif ($selected_style === 'style2') {
        ?>
        
        <?php 
    }
}

}