<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor instantva-testimonial Widget.
 *
 * Elementor widget that uses the instantva-testimonial control.
 *
 * @since 1.0.0
 */
class Elementor_InstantVA_Testimonial_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve instantva-testimonial widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'instantva-testimonial';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve instantva-testimonial widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'instantva Testimonial', 'elementor-instantva-testimonial-control' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve instantva-testimonial widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-carousel-loop';
	}

	/**
	 * Register instantva-testimonial widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'elementor-instantva-testimonial-control' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$repeater = new \Elementor\Repeater();
		$repeater->add_control(
			'list_content', [
				'label' => __( 'Content', 'elementor-instantva-testimonial-control' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => __( 'Beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas aspernatur aut odit aut fugit, sed. Beatae vitae dicta ripiscing elit, sed do euismod tempor incidunt. Labore et dolore magna aliqua ut enim ad minim adipiscing elit, sed do euismod tempor incidunt ut labore.' , 'elementor-instantva-testimonial-control' ),
				'label_block' => true,
				'show_label' => false,
			]
		);
		$repeater->add_control(
			'list_username', [
				'label' => __( 'Client Name', 'elementor-instantva-testimonial-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Client Name' , 'elementor-instantva-testimonial-control' ),
				'label_block' => true,
			]
		);
		$repeater->add_control(
			'list_designation', [
				'label' => __( 'Designation', 'elementor-instantva-testimonial-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Department' , 'elementor-instantva-testimonial-control' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'list_image',
			[
				'label' => esc_html__( 'Quote Image', 'elementor-farosa-04-control' ),
				'label_block' => true,
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => PLUGIN_BASE_URI. 'assets/img/testimonial-user-img.png' ,
				],
			]
		);
		$this->add_control(
			'list',
			[
				'label' => __( 'Repeater List', 'elementor-instantva-testimonial-control' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'list_content' => __( 'Content', 'elementor-instantva-testimonial-control' ),
						'list_username' => __( 'User Name', 'elementor-instantva-testimonial-control' ),
						'list_designation' => __( 'Designation Name', 'elementor-instantva-testimonial-control' ),
						'list_image' => __( 'User Image', 'elementor-instantva-testimonial-control' ),
					],
					[
						'list_content' => __( 'Content', 'elementor-instantva-testimonial-control' ),
						'list_username' => __( 'User Name', 'elementor-instantva-testimonial-control' ),
						'list_designation' => __( 'Designation Name', 'elementor-instantva-testimonial-control' ),
						'list_image' => __( 'User Image', 'elementor-instantva-testimonial-control' ),
					],
				],
				'heading_field' => '{{{ list_heading }}}',
			]
		);
		
		
        $this->end_controls_section();
	}


	/**
	 * Render instantva-testimonial widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<section class="testimonials-section" id="testimonial">
			<div class="container">
				<div class="testimonial_wrapper">
					<div class="row">
							<div class="owl-carousel owl-theme">
					<?php
					$count = 0;
					if ($settings['list']) {
						foreach ($settings['list'] as $item) {
							?>
							<div class="item">
								<div class="testimonials_content">
									<figure>
										<?php echo wp_get_attachment_image($item['list_image']['id'], 'full'); ?>
									</figure>
									<p><?php echo $item['list_content']; ?></p>
									<div class="testimonials_wrapper">
										<span class="testimonials_name d-block"><?php echo $item['list_username']; ?></span>
										<span class="testimonials_desc"><?php echo $item['list_designation']; ?></span>
									</div>
								</div>
							</div>
							<?php
								$count++;
							}
						}
						?>
					</div>
				</div>
			</div>
		</section>
		<?php
		?>
		<?php
	}	
}